

@echo off

set tiphome=%1
set arg2=%2
set ifix=tip22011_PM86702
set ifix_file=PM86702.zip

echo.
echo ******************************************************************
echo     Tivoli Integrated Portal IFIX %ifix% Installation
echo ******************************************************************
echo.


if '%tiphome%' == '' (
  goto ERROR_USAGE
)

if not '%arg2%' == '' (
  goto ERROR_USAGE
)

if not exist "%tiphome%" (
  goto ERROR_TIPHOME
)

echo Checking for a valid TIP 2.2.0.11 installation...
set props="%tiphome%\profiles\TIPProfile\installedApps\TIPCell\isc.ear\isclite.war\WEB-INF\config\isc.version.properties" 
if not exist "%props%" (
  goto ERROR_TIPHOME
)
findstr "isc.version=2.2.0.11" "%props%" 1>nul 2>&1
if not %ERRORLEVEL% == 0 (
 rem goto ERROR_TIPHOME
) 

echo Checking to see if this IFIX has already been installed...
if exist "%tiphome%\properties\ifixes\%ifix%" (
  goto ERROR_IFIX_INSTALLED
)

echo Backing up old files...
set file1=%tiphome%\profiles\TIPProfile\installedApps\TIPCell\isc.ear\isclite.war\secure\isclite\scripts\customizer.js
echo    Copying %file1% to %file1%.%ifix%
copy "%file1%" "%file1%.%ifix%"
if not %ERRORLEVEL% == 0 (
  goto ERROR_BACKUP
)
set file2=%tiphome%\profiles\TIPProfile\installedApps\TIPCell\isc.ear\isclite.war\secure\isclite\scripts\tipdojo\com\ibm\isclite\dijit\dashboard\themes\ISCTheme\portlet.css
echo    Copying %file2% to %file2%.%ifix%
copy "%file2%" "%file2%.%ifix%"
if not %ERRORLEVEL% == 0 (
  goto ERROR_BACKUP
)
set file3=%tiphome%\profiles\TIPProfile\installedApps\TIPCell\isc.ear\isclite.war\secure\isclite\scripts\tipdojo\com\ibm\isclite\dijit\dashboard\themes\TIPDark\portlet.css
echo    Copying %file3% to %file3%.%ifix%
copy "%file3%" "%file3%.%ifix%"
if not %ERRORLEVEL% == 0 (
  goto ERROR_BACKUP
)
set file4=%tiphome%\profiles\TIPProfile\installedApps\TIPCell\isc.ear\isclite.war\secure\isclite\scripts\tipdojo\com\ibm\isclite\dijit\dashboard\themes\TIPLight\portlet.css
echo    Copying %file4% to %file4%.%ifix%
copy "%file4%" "%file4%.%ifix%"
if not %ERRORLEVEL% == 0 (
  goto ERROR_BACKUP
)

set file5=%tiphome%\profiles\TIPProfile\installedApps\TIPCell\isc.ear\isclite.war\secure\isclite\scripts\tipdojo\com\ibm\isclite\dijit\dashboard\portlet.js
echo    Copying %file5% to %file5%.%ifix%
copy "%file5%" "%file5%.%ifix%"
if not %ERRORLEVEL% == 0 (
  goto ERROR_BACKUP
)

set file6=%tiphome%\profiles\TIPProfile\installedApps\TIPCell\isc.ear\isclite.war\secure\isclite\scripts\ffcontent.js
echo    Copying %file6% to %file6%.%ifix%
copy "%file6%" "%file6%.%ifix%"
if not %ERRORLEVEL% == 0 (
  goto ERROR_BACKUP
)

echo Installing new files...
copy ".\%ifix_file%" "%tiphome%"
if not %ERRORLEVEL% == 0 (
  goto ERROR_INSTALL
)
pushd "%tiphome%"
"%tiphome%\java\bin\jar" xvf ".\\%ifix_file%"
if not %ERRORLEVEL% == 0 (
  popd
  goto ERROR_INSTALL
)

del "%tiphome%\%ifix_file%" 1>nul 2>&1
popd

if not exist "%tiphome%\properties\ifixes" (
  mkdir "%tiphome%\properties\ifixes"
)

date /T > "%tiphome%\properties\ifixes\%ifix%"
time /T >> "%tiphome%\properties\ifixes\%ifix%"

goto SUCCESS

:ERROR_INSTALL
   echo.
   echo Error: Installing new files failed.
   goto ERROR 

:ERROR_BACKUP
   echo.
   echo Error: Backing up old files failed. 
   goto ERROR

:ERROR_IFIX_INSTALLED
   echo.
   echo Error: IFIX %ifix% has already been installed.
   goto ERROR

:ERROR_TIPSERVER
   echo.
   echo Error: The TIP Server must be stopped before the IFIX can be installed.
   goto ERROR

:ERROR_TIPHOME
   echo.
   echo Error: '%tiphome%' is not a valid 2.2.0.11 TIP install location.
   echo Example: install_ifix.bat c:\IBM\tivoli\tipv2
   goto ERROR
 
:ERROR_USAGE
   echo.
   echo Usage: install_ifix.bat TIP_HOME
   echo Example: install_ifix.bat c:\ibm\tivoli\tipv2

:ERROR
   echo.
   echo TIP IFIX install did not complete successfully.
   echo.
   exit /b 1

:SUCCESS
   echo.
   echo TIP IFIX install finished successfully.
   echo.
   echo.
   exit /b 0


