#!/bin/sh

tiphome=$1
ifix=tip22011_PM86702
ifix_file=PM86702.zip
ihome=`pwd`

error_exit() {
   echo
   echo "TIP IFIX install did not complete successfully."
   echo
   exit 1
}

error_usage() {
   echo
   echo "Usage: install_ifix.sh  TIP_HOME"
   echo "Example: install_ifix.sh  /opt/IBM/tivoli/tipv2"
   error_exit
}

error_tiphome() {
   echo
   echo "Error: $tiphome is not a valid 2.2.0.11 TIP install location."
   echo "Example: install_ifix.sh  /opt/IBM/tivoli/tipv2"
   error_exit
}


error_ifix_installed() {
   echo
   echo "Error: IFIX $ifix has already been installed."
   error_exit
}

error_backup() {
   echo
   echo "Error: Backing up old files failed."
   error_exit
}

error_install() {
  echo
  echo "Error: Installing new files failed."
  error_exit
}

echo 
echo "******************************************************************"
echo "     Tivoli Integrated Portal IFIX $ifix Installation "
echo "******************************************************************"
echo 

if [ $# != 1 ]; then
  error_usage
fi

if [ ! -d "$tiphome" ]; then
  error_tiphome
fi

echo "Checking for a valid TIP 2.2.0.11 installation..."
props="$tiphome/profiles/TIPProfile/installedApps/TIPCell/isc.ear/isclite.war/WEB-INF/config/isc.version.properties"
if [ ! -f "$props" ]; then
  error_tiphome
fi
grep "isc.version=2.2.0.11" "$props" >/dev/null 2>&1
if [ "$?" != "0" ]; then
  error_tiphome
fi

echo "Checking to see if this IFIX has already been installed..."
if [ -f "$tiphome/properties/ifixes/$ifix" ]; then
  error_ifix_installed
fi

if [ ! -d "$tiphome/properties/ifixes" ]; then
  mkdir "$tiphome/properties/ifixes"
fi

echo "Backing up old files..."
file1="$tiphome/profiles/TIPProfile/installedApps/TIPCell/isc.ear/isclite.war/secure/isclite/scripts/customizer.js" 
echo "   Copying $file1 to $file1.$ifix"
cp "$file1" "$file1.$ifix"
if [ $? != "0" ]; then
  error_backup
fi
file2="$tiphome/profiles/TIPProfile/installedApps/TIPCell/isc.ear/isclite.war/secure/isclite/scripts/tipdojo/com/ibm/isclite/dijit/dashboard/themes/ISCTheme/portlet.css" 
echo "   Copying $file2 to $file2.$ifix"
cp "$file2" "$file2.$ifix"
if [ $? != "0" ]; then
  error_backup
fi
file3="$tiphome/profiles/TIPProfile/installedApps/TIPCell/isc.ear/isclite.war/secure/isclite/scripts/tipdojo/com/ibm/isclite/dijit/dashboard/themes/TIPDark/portlet.css" 
echo "   Copying $file3 to $file3.$ifix"
cp "$file3" "$file3.$ifix"
if [ $? != "0" ]; then
  error_backup
fi
file4="$tiphome/profiles/TIPProfile/installedApps/TIPCell/isc.ear/isclite.war/secure/isclite/scripts/tipdojo/com/ibm/isclite/dijit/dashboard/themes/TIPLight/portlet.css" 
echo "   Copying $file4 to $file4.$ifix"
cp "$file4" "$file4.$ifix"
if [ $? != "0" ]; then
  error_backup
fi
file5="$tiphome/profiles/TIPProfile/installedApps/TIPCell/isc.ear/isclite.war/secure/isclite/scripts/tipdojo/com/ibm/isclite/dijit/dashboard/portlet.js" 
echo "   Copying $file5 to $file5.$ifix"
cp "$file5" "$file5.$ifix"
if [ $? != "0" ]; then
  error_backup
fi

file6="$tiphome/profiles/TIPProfile/installedApps/TIPCell/isc.ear/isclite.war/secure/isclite/scripts/ffcontent.js" 
echo "   Copying $file6 to $file6.$ifix"
cp "$file6" "$file6.$ifix"
if [ $? != "0" ]; then
  error_backup
fi

echo "Installing new files..."
cp "$ifix_file" "$tiphome"
if [ $? != "0" ]; then
  error_install
fi

cd "$tiphome"

"$tiphome/java/bin/jar" xvf "./$ifix_file"  
if [ $? != "0" ]; then
  rm "./$iix_file" >/dev/null 2>&1
  cd "$ihome"
  error_install
fi

rm "./$ifix_file" >/dev/null 2>&1
cd "$ihome"

if [ ! -d "$tiphome/properties/ifixes" ]; then
  mkdir "$tiphome/properties/ifixes"
fi

date > "$tiphome/properties/ifixes/$ifix"

echo
echo "TIP IFIX install finished successully."
echo
